@@ -189,6 +189,16 @@
                 "inode NOT NULL, " \
                 "comment);"
 
+/* The window table survives database builds. */
+#define SQL_CREATE_TABLE_WINDOW \
+        "CREATE TABLE IF NOT EXISTS window (" \
+                "name PRIMARY KEY, " \
+                "x, " \
+                "y, " \
+                "width, " \
+                "height, " \
+                "maximized);"
+
 #define SQL_CREATE_VIEW_AVAILABLE \
         "CREATE VIEW IF NOT EXISTS available AS " \
                 "SELECT game.*, bios.description AS bios, " \
@@ -789,6 +799,8 @@ db_parser_start_element_game (ParserData *data,
                 db_parser_bind_text (stmt, "@category", category);
         else if (local_error != NULL)
                 g_propagate_error (error, local_error);
+
+        g_free (category);
 #endif
 }
 
@@ -1294,6 +1306,7 @@ db_create_tables (GError **error)
                 && gva_db_execute (SQL_CREATE_TABLE_CONTROL, error)
                 && gva_db_execute (SQL_CREATE_TABLE_DIPVALUE, error)
                 && gva_db_execute (SQL_CREATE_TABLE_PLAYBACK, error)
+                && gva_db_execute (SQL_CREATE_TABLE_WINDOW, error)
                 && gva_db_execute (SQL_CREATE_VIEW_AVAILABLE, error);
 }
 
@@ -1578,9 +1591,9 @@ gva_db_execute (const gchar *sql,
 /**
  * gva_db_get_table:
  * @sql: an SQL statement
- * @result: return location for the result
- * @rows: return location for the number of rows in the result
- * @columns: return location for the number of columns in the result
+ * @result: return location for the result, or %NULL
+ * @rows: return location for the number of rows in the result, or %NULL
+ * @columns: return location for the number of columns in the result, or %NULL
  * @error: return location for a #GError, or %NULL
  *
  * Executes the given SQL statement and returns the results as a string
@@ -1601,25 +1614,28 @@ gva_db_get_table (const gchar *sql,
 {
         char **table;
         char *errmsg;
+        int local_rows = 0;
+        int local_columns = 0;
         gint errcode;
 
         g_return_val_if_fail (db != NULL, FALSE);
         g_return_val_if_fail (sql != NULL, FALSE);
-        g_return_val_if_fail (result != NULL, FALSE);
-        g_return_val_if_fail (rows != NULL, FALSE);
-        g_return_val_if_fail (columns != NULL, FALSE);
 
         errcode = sqlite3_get_table (
-                db, sql, &table, rows, columns, &errmsg);
+                db, sql, &table, &local_rows, &local_columns, &errmsg);
 
         if (errcode == SQLITE_OK)
         {
-                gint length, ii;
+                if (result != NULL)
+                {
+                        gint length, ii;
+
+                        length = (local_rows + 1) * (local_columns);
+                        *result = g_new0 (gchar *, length + 1);
+                        for (ii = 0; ii < length; ii++)
+                                (*result)[ii] = g_strdup (table[ii]);
+                }
 
-                length = (*rows + 1) * (*columns);
-                *result = g_new0 (gchar *, length + 1);
-                for (ii = 0; ii < length; ii++)
-                        (*result)[ii] = g_strdup (table[ii]);
                 sqlite3_free_table (table);
         }
         else
@@ -1628,6 +1644,11 @@ gva_db_get_table (const gchar *sql,
                 sqlite3_free (errmsg);
         }
 
+        if (rows != NULL)
+                *rows = local_rows;
+        if (columns != NULL)
+                *columns = local_columns;
+
         return (errcode == SQLITE_OK);
 }
 
@@ -1797,6 +1818,8 @@ gva_db_is_older_than (const gchar *filename)
         time_t db_mtime;
         struct stat st;
 
+        g_return_val_if_fail (filename != NULL, FALSE);
+
         if (g_stat (gva_db_get_filename (), &st) < 0)
                 return FALSE;
 
@@ -1856,6 +1879,11 @@ gva_db_needs_rebuilt (void)
         reason = "the database build ID does not match the MAME version";
         TEST_CASE (strstr (mame_version, db_build_id) == NULL);
 
+#ifdef CATEGORY_FILE
+        reason = "the category file changed";
+        TEST_CASE (gva_db_is_older_than (CATEGORY_FILE));
+#endif
+
         /* ... add more tests here ... */
 
 #undef TEST_CASE
